@@ -1,11 +1,11 @@
-__version__ = "0.9.8"
+__version__ = "0.9.9"
 
 __all__ = []
 
-from .s_plots import __all__ as sp_all
-from .i_plots import __all__ as ip_all
 from .g_utils import __all__ as gu_all
 from .vr_parser import __all__ as vp_all
+from .s_plots import __all__ as sp_all
+from .i_plots import __all__ as ip_all
 from .sio import __all__ as si_all
 from .widgets import __all__ as wg_all
 __all__.extend(vp_all)
@@ -18,15 +18,15 @@ __all__.extend(wg_all)
 
 
 # Access all functions through root modile pivotpy
-from .s_plots import *
-from .i_plots import *
 from .g_utils import *
 from .vr_parser import *
+from .s_plots import *
+from .i_plots import *
 from .sio import *
 from .widgets import *
-from matplotlib.pyplot import show,savefig
+from matplotlib.pyplot import show as _show,savefig as _savefig
 
-mpl_imported=['show','savefig']
+mpl_imported=['_show','_savefig']
 __all__.extend(mpl_imported)
 
 # Register 'RGB' colormap in current session
